@@ -2,5 +2,5 @@
 from python_helper.api.src.service import LogHelper as log
 from python_helper.api.src.service import ObjectHelper, SettingHelper, StringHelper, EnvironmentHelper, ReflectionHelper
 from python_helper.api.src.domain import Constant
-from python_helper.api.src.annotation.EnvironmentAnnotation import EnvironmentVariable, MethodAnnotation
+from python_helper.api.src.annotation import EnvironmentVariable, MethodAnnotation
 from python_helper.api.src.helper import ObjectHelperHelper, SettingHelperHelper, SettingHelperHelper, LogHelperHelper
